/*
 * disable-paste.c - trivial program to stop gpm from pasting the
 * current selection until the next user action
 *
 * Copyright (C) 1998 Ian Zimmerman <itz@rahul.net>
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 ********/

static char rcsid[] = "$Id: disable-paste.c,v 1.2 2000/01/17 22:23:03 rubini Exp $";

#include <unistd.h>             /* execv */

static char* argv[] = {
  "gpm",
  "-A",
  "-q",
  0 
};

int 
main()
{
  execv(SBINDIR "/gpm", argv);
  exit(127);
}
